@@ -1,9 +1,11 @@
+from torch import Tensor
 from torch.nn import (
     AvgPool2d,
     Conv2d,
     CrossEntropyLoss,
     Dropout,
     Flatten,
+    Identity,
     Linear,
     MaxPool2d,
     MSELoss,
@@ -13,18 +15,30 @@ from torch.nn import (
     ZeroPad2d,
 )
 
-from backpack.extensions.backprop_extension import BackpropExtension
+from backpack.custom_module.branching import SumModule
+from backpack.custom_module.scale_module import ScaleModule
 from backpack.extensions.curvature import Curvature
+from backpack.extensions.secondorder.base import SecondOrderBackpropExtension
 from backpack.extensions.secondorder.hbp.hbp_options import (
     BackpropStrategy,
     ExpectationApproximation,
     LossHessianStrategy,
 )
 
-from . import activations, conv2d, dropout, flatten, linear, losses, padding, pooling
+from . import (
+    activations,
+    conv2d,
+    custom_module,
+    dropout,
+    flatten,
+    linear,
+    losses,
+    padding,
+    pooling,
+)
 
 
-class HBP(BackpropExtension):
+class HBP(SecondOrderBackpropExtension):
     def __init__(
         self,
         curv_type,
@@ -54,6 +68,9 @@ class HBP(BackpropExtension):
                 ReLU: activations.HBPReLU(),
                 Sigmoid: activations.HBPSigmoid(),
                 Tanh: activations.HBPTanh(),
+                SumModule: custom_module.HBPSumModule(),
+                ScaleModule: custom_module.HBPScaleModule(),
+                Identity: custom_module.HBPScaleModule(),
             },
         )
 
@@ -115,6 +132,11 @@ class KFAC(HBP):
     def get_num_mc_samples(self):
         return self._mc_samples
 
+    def accumulate_backpropagated_quantities(
+        self, existing: Tensor, other: Tensor
+    ) -> Tensor:  # noqa: D102
+        return existing + other
+
 
 class KFRA(HBP):
     """
